/* -------------------------------------------------------
                      tbasic_ports.h

     Deklarationen der I/O Ports fuer STM32F030
     TinyBasic

     21.12.2023  R. Seelig
   ------------------------------------------------------ */


#ifndef in_tbasic_ports
  #define in_tbasic_ports

  #include "sysf030_init.h"

  // GPIO Anschluesse, an denen normalerweise ein Systemquarz angeschlossen ist,
  // wenn der Controller mit externem Takt betrieben wird. PF0 und PF1 sind nicht
  // in sysf030_init.h deklariert und deshalb hier. Im Hauptprogramm nicht
  // vergessen mittels

  //            rcc_periph_clock_enable(RCC_GPIOF);

  // den Takt fuer die GPIOs einzuschalten

  #define PF0_output_init()  ( gpio_mode_setup(GPIOF, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, GPIO0) )
  #define PF0_input_init()   ( gpio_mode_setup(GPIOF, GPIO_MODE_INPUT, GPIO_PUPD_PULLUP, GPIO0) )
  #define PF0_set()          ( gpio_set(GPIOF, GPIO0) )
  #define PF0_clr()          ( gpio_clear(GPIOF, GPIO0) )
  #define is_PF0()           ( (gpio_get(GPIOF, GPIO0)) )

  #define PF1_output_init()  ( gpio_mode_setup(GPIOF, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, GPIO1) )
  #define PF1_input_init()   ( gpio_mode_setup(GPIOF, GPIO_MODE_INPUT, GPIO_PUPD_PULLUP, GPIO1) )
  #define PF1_set()          ( gpio_set(GPIOF, GPIO1) )
  #define PF1_clr()          ( gpio_clear(GPIOF, GPIO1) )
  #define is_PF1()           ( (gpio_get(GPIOF, GPIO1)) )

  #define IO0_output_init()      PA0_output_init()
  #define IO1_output_init()      PA1_output_init()
  #define IO2_output_init()      PA2_output_init()
  #define IO3_output_init()      PA3_output_init()
  #define IO4_output_init()      PA4_output_init()
  #define IO5_output_init()      PA5_output_init()
  #define IO6_output_init()      PA6_output_init()
  #define IO7_output_init()      PA7_output_init()
  #define IO8_output_init()      PB1_output_init()
  #define IO9_output_init()      PA13_output_init()
  #define IO10_output_init()     PA14_output_init()
  #define IO11_output_init()     PF1_output_init()

  #define IO0_set()              PA0_set()
  #define IO1_set()              PA1_set()
  #define IO2_set()              PA2_set()
  #define IO3_set()              PA3_set()
  #define IO4_set()              PA4_set()
  #define IO5_set()              PA5_set()
  #define IO6_set()              PA6_set()
  #define IO7_set()              PA7_set()
  #define IO8_set()              PB1_set()
  #define IO9_set()              PA13_set()
  #define IO10_set()             PA14_set()
  #define IO11_set()             PF1_set()

  #define IO0_clr()              PA0_clr()
  #define IO1_clr()              PA1_clr()
  #define IO2_clr()              PA2_clr()
  #define IO3_clr()              PA3_clr()
  #define IO4_clr()              PA4_clr()
  #define IO5_clr()              PA5_clr()
  #define IO6_clr()              PA6_clr()
  #define IO7_clr()              PA7_clr()
  #define IO8_clr()              PB1_clr()
  #define IO9_clr()              PA13_clr()
  #define IO10_clr()             PA14_clr()
  #define IO11_clr()             PF1_clr()

  #define IO0_input_init()       PA0_input_init()
  #define IO1_input_init()       PA1_input_init()
  #define IO2_input_init()       PA2_input_init()
  #define IO3_input_init()       PA3_input_init()
  #define IO4_input_init()       PA4_input_init()
  #define IO5_input_init()       PA5_input_init()
  #define IO6_input_init()       PA6_input_init()
  #define IO7_input_init()       PA7_input_init()
  #define IO8_input_init()       PB1_input_init()
  #define IO9_input_init()       PA13_input_init()
  #define IO10_input_init()      PA14_input_init()
  #define IO11_input_init()      PF1_input_init()

  #define is_IO0()               is_PA0()
  #define is_IO1()               is_PA1() >> 1
  #define is_IO2()               is_PA2() >> 2
  #define is_IO3()               is_PA3() >> 3
  #define is_IO4()               is_PA4() >> 4
  #define is_IO5()               is_PA5() >> 5
  #define is_IO6()               is_PA6() >> 6
  #define is_IO7()               is_PA7() >> 7
  #define is_IO8()               is_PB1() >> 1
  #define is_IO9()               is_PA13() >> 13
  #define is_IO10()              is_PA14() >> 14  
  #define is_IO11()              is_PF1() >> 1

  #define autorun_init()         PF0_input_init()
  #define is_autorun()           !is_PF0()

#endif
